pocketpose.models.registry - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.models.registry`

Registry for models.

This module contains a registry for models. The registry is used to register models, which can then be retrieved by name using the model factory.

Example:

      >>> from pocketpose.models.registry import model_registry
      >>> @model_registry.register("model1")

## Module Contents

pocketpose.models.registry.model_registry